@@ -114,7 +114,7 @@ bootstrapCrossValidation <- function(object,
             try2predict <- try(pred.b <- do.call(predictHandlerFun,
                                                  c(list(object=fit.b,newdata=val.b,times=times),extraArgs)))
         }
-        if (inherits(try2predict,"try-error")==TRUE){
+        if (inherits(x=try2predict,what="try-error")==TRUE){
             if (verbose==TRUE) warning(paste("During bootstrapping: prediction for model ",class(fit.b)," failed in step ",b),immediate.=TRUE)
             NULL}
         else{
@@ -190,7 +190,7 @@ bootstrapCrossValidation <- function(object,
                                  NAOK=TRUE,
                                  PACKAGE="pec")$pec
                 else
-                    pecOut <- .C("pec",pec=double(NT),as.double(Y[vindex.b]),as.double(status[vindex.b]),as.double(times),as.double(pred.b),as.double(ipcwTimes.b),as.double(IPCW.subjectTimes.b),as.integer(NV),as.integer(NT),as.integer(ipcw$dim),as.integer(is.null(dim(pred.b))),NAOK=TRUE,PACKAGE="pec")$pec
+                    pecOut <- .C("pecSRC",pec=double(NT),as.double(Y[vindex.b]),as.double(status[vindex.b]),as.double(times),as.double(pred.b),as.double(ipcwTimes.b),as.double(IPCW.subjectTimes.b),as.integer(NV),as.integer(NT),as.integer(ipcw$dim),as.integer(is.null(dim(pred.b))),NAOK=TRUE,PACKAGE="pec")$pec
             }
         })
     }
