@@ -27,14 +27,14 @@ print.pec <- function(x,
     # {{{ echo models
     cat("Prediction models:\n\n")
     printModels <- sapply(x$models,function(m){
-                              if (class(m) %in% c("character","call"))
-                                  m
-                              else
-                                  if (class(try(m$call,silent=TRUE))=="try-error")
-                                      "unknown formula"
-                                  else
-                                      m$call
-                          })
+        if (class(m) %in% c("character","call"))
+            m
+        else
+            if (inherits(try(m$call,silent=TRUE),what="try-error"))
+                "unknown formula"
+        else
+            m$call
+    })
     print(printModels,quote=FALSE)
     # }}}
     # {{{ echo response
